import { scaleOrdinal } from 'd3';


const colorScale = scaleOrdinal()
	.domain(['apple', 'lemon'])
	.range(['#c11d1d', '#eae600'])

const radiusScale = scaleOrdinal()
	.domain(['apple', 'lemon'])
	.range(['80', '50'])

const xPosition = (d, i) => i * 200 + 80;

export const fruitBowl = (selection, props) => {
  
  const { fruits, 
         height, 
         setSelectedFruit,
         selectedFruit} = props;
  const circles = selection.selectAll('circle')
  												 .data(fruits, d => d.id);
  
  circles
    .enter().append('circle')
        .attr('cy', height / 2)
  			.attr('cx', xPosition)
  			.attr('r', 0)
  	.merge(circles)
  			.on('mouseover', d => setSelectedFruit(d.id))
  			.on('mouseout', () => setSelectedFruit(null))
  			.attr('stroke', d => 
             d.id === selectedFruit
             ? 'black'
             : 'none')
  			.attr('stroke-width', 5)
        .attr('fill', d => colorScale(d.type))
  		.transition().duration(1000)
        .attr('r', d => radiusScale(d.type))
  			.attr('cx', xPosition);
  circles.exit()
    .transition().duration(1000)
    	.attr('r', 0)
    .remove();
  
}



























